summaryrefslogtreecommitdiff
path: root/buildscripts/resmokelib/logging/loggers.py
diff options
context:
space:
mode:
authorYves Duhem <yves.duhem@mongodb.com>2018-02-27 11:29:41 -0500
committerYves Duhem <yves.duhem@mongodb.com>2018-02-27 11:29:46 -0500
commit4a69dcaf78f29cf440ada961c7e59de6b5dde111 (patch)
treeaceb8f015e234f940c94e67b5a756e1a7f8baab3 /buildscripts/resmokelib/logging/loggers.py
parenta77297dbe34d5cd838a4da55e9d83dc70c510bba (diff)
downloadmongo-4a69dcaf78f29cf440ada961c7e59de6b5dde111.tar.gz
SERVER-33476 Rename CustomBehavior to Hook
Diffstat (limited to 'buildscripts/resmokelib/logging/loggers.py')
-rw-r--r--buildscripts/resmokelib/logging/loggers.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/buildscripts/resmokelib/logging/loggers.py b/buildscripts/resmokelib/logging/loggers.py
index bc26174081b..28da3b9744c 100644
--- a/buildscripts/resmokelib/logging/loggers.py
+++ b/buildscripts/resmokelib/logging/loggers.py
@@ -149,9 +149,9 @@ class ExecutorRootLogger(RootLogger):
"""Create a new TestQueueLogger that will be a child of the "tests" root logger."""
return TestQueueLogger(test_kind, self.tests_root_logger)
- def new_hook_logger(self, behavior_class, fixture_logger):
+ def new_hook_logger(self, hook_class, fixture_logger):
"""Create a new child hook logger."""
- return HookLogger(behavior_class, fixture_logger, self.tests_root_logger)
+ return HookLogger(hook_class, fixture_logger, self.tests_root_logger)
class JobLogger(BaseLogger):
@@ -315,14 +315,14 @@ class TestQueueLogger(BaseLogger):
class HookLogger(BaseLogger):
- def __init__(self, behavior_class, fixture_logger, tests_root_logger):
+ def __init__(self, hook_class, fixture_logger, tests_root_logger):
"""Initialize a HookLogger.
:param behavior_class: the hook's name (e.g. CheckReplDBHash, ValidateCollections, etc.).
:param fixture_logger: the logger for the fixtures logs.
:param tests_root_logger: the root logger for the tests logs.
"""
- logger_name = "{}:job{:d}".format(behavior_class, fixture_logger.job_num)
+ logger_name = "{}:job{:d}".format(hook_class, fixture_logger.job_num)
BaseLogger.__init__(self, logger_name, parent=fixture_logger)
self.test_case_logger = BaseLogger(logger_name, parent=tests_root_logger)
@@ -315,14 +315,14 @@ class TestQueueLogger(BaseLogger):
"""Initialize a HookLogger.
- :param behavior_class: the hook's name (e.g. CheckReplDBHash, ValidateCollections, etc.).
+ :param hook_class: the hook's name (e.g. CheckReplDBHash, ValidateCollections, etc.).
:param fixture_logger: the logger for the fixtures logs.
:param tests_root_logger: the root logger for the tests logs.